library(ggplot2)


##Part 1 - Shell whorl arc length growth rate along the shell ontogeny.----------------------------------------------------------------------
growth_rate_data <- read.csv("C:/Liew Thor Seng/PhD thesis/On growth and form of two heteromorphic terrestrial gastropod snails/comment from Menno Reuben, Heike/R/Part 1 growth rate.csv")
growth_rate <- growth_rate_data[,7]
ontogeny_axis <- growth_rate_data[,3]
growth_stage <- growth_rate_data[,2]
growth_experiment <- growth_rate_data[,4]
total_whorl_length_added <- growth_rate_data[,5]

normality_test_spire_growth = shapiro.test(growth_rate[1:30])
normality_test_tuba_growth = shapiro.test(growth_rate[31:65])
normality_test_spire_axis = shapiro.test(ontogeny_axis[1:30])
normality_test_tuba_axis = shapiro.test(ontogeny_axis[31:65])

spire = cor.test(growth_rate[1:30],ontogeny_axis[1:30],method = "spearman")
tuba = cor.test(growth_rate[31:65],ontogeny_axis[31:65],method = "spearman")

# Figure 4
(d <- qplot(ontogeny_axis,growth_rate, colour = growth_experiment,size=I(4),shape = growth_stage))
d  + xlim(0, 20) + ylim(0, 0.7) + scale_shape_manual(values=c(4,17))

# (Supplemental Information File S10) Absolute shell whorl arc length added during the growth experiment 
(d <- qplot(ontogeny_axis,total_whorl_length_added, colour = growth_experiment,size=I(4),shape = growth_stage))
d  + xlim(0, 20) + ylim(0, 4) + scale_shape_manual(values=c(4,17))

## Part 2 - Aperture ontogeny profile changes between spire and tuba growth phases-----------------------------
# Part 2 (a) Aperture form changes between spire and tuba growth phases.----------------------
##shape
aperture_forms<- read.csv("C:/Liew Thor Seng/PhD thesis/On growth and form of two heteromorphic terrestrial gastropod snails/comment from Menno Reuben, Heike/R/Part 2a aperture form changes.csv")
specimens <- aperture_forms[,1]
stages <- aperture_forms[,5]
perimeter <- aperture_forms[,3]
ontogeny_axis_ <- aperture_forms[,4]
Normalised_EFA_coeefficient <- aperture_forms [,6:35]

pca <- prcomp(Normalised_EFA_coeefficient)
plot(pca)
summary(pca)
pca_scores <- pca$x
# Figure 5A
(d <- qplot(ontogeny_axis_, pca_scores[,1], colour = specimens,size=I(4),shape = stages))
d  + xlim(0, 20) + ylim(-0.125, 0.075) + scale_shape_manual(values=c(20,17,4))

## size
# Figure 5B
(d <- qplot(ontogeny_axis_, perimeter, colour = specimens,size=I(4),shape = stages))
d  + xlim(0, 20) + ylim(0, 3) + scale_shape_manual(values=c(20,17,4))

# linear regression of the spire aperture size
perimeter_of_spire_only <- aperture_forms[(c(5:7,15:33)),3]
ontogeny_axis_of_spire_only <- aperture_forms[(c(5:7,15:33)),4]
specimens_spire_only <- aperture_forms[(c(5:7,15:33)),1]
qplot(ontogeny_axis_of_spire_only,perimeter_of_spire_only, colour = specimens_spire_only )
linear_regression_spire_perimeter <- lm(perimeter_of_spire_only~ontogeny_axis_of_spire_only)
summary(linear_regression_spire_perimeter)


#Part 2 (b) Aperture growth trajectory changes between spire and tuba growth phases.--------------
#rotation
animal_orientation<- read.csv("C:/Liew Thor Seng/PhD thesis/On growth and form of two heteromorphic terrestrial gastropod snails/comment from Menno Reuben, Heike/R/Part 2b animal orientation.csv")
stage <- animal_orientation[,3]
ontogeny_axis <- animal_orientation[,7]
x_rotation <- animal_orientation[,4]
y_rotation  <- animal_orientation[,5]
z_rotation  <- animal_orientation[,6]
#Figure 6A
(d <- qplot(ontogeny_axis, x_rotation, size=I(4),shape = stage))
d  + xlim(0, 20) + ylim(-15, 20) + scale_shape_manual(values=c(20,17,4))
#Figure 6B
(d <- qplot(ontogeny_axis, y_rotation, size=I(4),shape = stage))
d  + xlim(0, 20) + ylim(-30, 5) + scale_shape_manual(values=c(20,17,4))
#Figure 6C
(d <- qplot(ontogeny_axis, z_rotation, size=I(4),shape = stage))
d  + xlim(0, 20) + ylim(-15, 20) + scale_shape_manual(values=c(20,17,4))

#curvature and torsion (Figure 7)
spiral_curvature_torsion <- read.csv("C:/Liew Thor Seng/PhD thesis/On growth and form of two heteromorphic terrestrial gastropod snails/comment from Menno Reuben, Heike/R/Part 2b curvature and torsion.csv")
ontogeny_axis <- spiral_curvature_torsion[,1]
curvature <- spiral_curvature_torsion[,2]
torsion <- spiral_curvature_torsion[,3]
x_coord_spiral <- spiral_curvature_torsion[,4]
y_coord_spiral <- spiral_curvature_torsion[,5]
z_coord_spiral <- spiral_curvature_torsion[,6]

par(mfrow=c(2,2))
plot(ontogeny_axis,curvature)
plot(ontogeny_axis,torsion)
library(scatterplot3d)
scatterplot3d(x_coord_spiral,y_coord_spiral ,z_coord_spiral)
qplot(x_coord_spiral,y_coord_spiral, colour = curvature)
qplot(x_coord_spiral,z_coord_spiral, colour = torsion)
qplot(y_coord_spiral,z_coord_spiral, colour = torsion)

##Part 3 - Number of times and trend in the switching between whorl and rib growing mode.------------
# Part 3 (a) Intraspecific variation of total number of ribs
# correlation between number of ribs on spire and tuba
ribs_density_of_17_adult_shell <- read.csv("C:/Liew Thor Seng/PhD thesis/On growth and form of two heteromorphic terrestrial gastropod snails/comment from Menno Reuben, Heike/R/Part 3a correlation between number of ribs on spire and tuba part.csv")
Ribs_number_on_tuba <- ribs_density_of_17_adult_shell[,2]
Ribs_number_on_spire <- ribs_density_of_17_adult_shell[,3]
shapiro.test(Ribs_number_on_tuba)
shapiro.test(Ribs_number_on_spire)
cor.test(Ribs_number_on_tuba,Ribs_number_on_spire,method = "pearson")
plot(Ribs_number_on_spire,Ribs_number_on_tuba)

#correlation test between number of ribs and arc length
ribs_density_and_arclength_of_35_shell_spire <- read.csv("C:/Liew Thor Seng/PhD thesis/On growth and form of two heteromorphic terrestrial gastropod snails/comment from Menno Reuben, Heike/R/Part 3a Ribs and arc length on spire 20122013.csv")
Ribs_number_on_spire_of_juvenile <- ribs_density_and_arclength_of_35_shell_spire[,6]
arc_length_of_spire_of_juvenile <- ribs_density_and_arclength_of_35_shell_spire[,5]
shapiro.test(Ribs_number_on_spire_of_juvenile)
shapiro.test(arc_length_of_spire_of_juvenile)
cor.test(Ribs_number_on_spire_of_juvenile,arc_length_of_spire_of_juvenile,method = "pearson")
plot(arc_length_of_spire_of_juvenile,Ribs_number_on_spire_of_juvenile)

#Part 3 (b) Switching trends between the whorl growing to the rib growing mode.--------
switching_growth_mode_pattern<- read.csv("C:/Liew Thor Seng/PhD thesis/On growth and form of two heteromorphic terrestrial gastropod snails/comment from Menno Reuben, Heike/R/Part 3b Switching growth mode.csv")
accummulative_ontogeny_axis <- switching_growth_mode_pattern[,3]
interval_ontogeny_axis <- switching_growth_mode_pattern[,4]
stage_spire_or_tuba <- switching_growth_mode_pattern[,5]
specimens_label <- switching_growth_mode_pattern[,1]

shell_with_complete_spire <- subset(switching_growth_mode_pattern, Complete.spire == 'yes',select=c(SPECIMEN , whorl.lengths ,cumulative.whorl.length,before..Before_constriction..or.after..After_constriction..constriction,number.of.ribs.on.complete.spire ))  
shell_with_complete_spire_and_spire_only <- subset(shell_with_complete_spire, before..Before_constriction..or.after..After_constriction..constriction == 'Before_constriction',select=c(SPECIMEN , whorl.lengths ,cumulative.whorl.length,before..Before_constriction..or.after..After_constriction..constriction,number.of.ribs.on.complete.spire ))  

(d <- qplot(shell_with_complete_spire [,3],shell_with_complete_spire [,2], colour = shell_with_complete_spire [,5],size=I(1),shape = shell_with_complete_spire[,4]))
d + scale_colour_gradientn(colours = rainbow(7)) + xlim(0, 20) + ylim(0, 0.7) + scale_shape_manual(values=c(4,17))

##Supplemental Information File S3. Correlation between 2D and 3D arc length measurement of three specimens.------
#appendix 2D arc length vs 3D arc length
##some 3D arc length cannot be determined from the 3D model because the resolution of the Ct-scan cannot capture the fine ribs (especially those near the protoconch)
## specimens_127: ribs no. 1-8, 48-49, 73-74, & 80-82.
## specimens_85: ribs no. 1-3, & 54.
## specimens_125: ribs no. 1-6, 102.
relationship_between_2D_and_3D_arc_length<- read.csv("C:/Liew Thor Seng/PhD thesis/On growth and form of two heteromorphic terrestrial gastropod snails/comment from Menno Reuben, Heike/R/Appendix File S3 2D arc length and 3D arc length.csv")
arc_length_2D <- relationship_between_2D_and_3D_arc_length[,2]
arc_length_3D <- relationship_between_2D_and_3D_arc_length[,3]

shapiro.test(arc_length_2D)
shapiro.test(arc_length_3D)
plot(arc_length_2D,arc_length_3D)
cor.test(arc_length_2D,arc_length_3D,method = "spearman")
